@@ -1,4 +1,4 @@
-#!/usr/bin/perl 
+#!/usr/bin/env perl
 use FindBin;
 use lib $FindBin::RealBin."/../lib";
 use lib $FindBin::RealBin."../..";
@@ -20,7 +20,7 @@ my @credentials=(
                './credentials.pl', 
              ); 
 
-
+our $VERSION=0.093; 
 ######### code for multiiple -n x arguments treat as single joined with |. Not handled with getopts. 
 $opt{n}=[]; 
 for my $i (0..$#ARGV)
@@ -41,12 +41,12 @@ for my $i (0..$#ARGV)
 @ARGV=grep { defined $_ } @ARGV; 
 $opt{n}=join('|',@{$opt{n}}); 
 $opt{n} or delete $opt{n}; 
+$opt{a}=1; 
 #########
 
-getopts('eotf:Nhn:s:SO:g:', \%opt) or help("Aborted! -h for help "); 
+getopts('a:c:eotf:Nhn:s:SO:g:', \%opt) or help("Aborted! -h for help "); 
 
 my $ig; 
-
 # IG Credentials needed. 
 # You can add them to enviroment variables as bellow or 
 # directly hardcode them below. 
@@ -55,6 +55,9 @@ my $ig;
 
 my $capital; # hardcode your capital here if you want. 
 
+$opt{c}.='/credentials.pl' if ($opt{c} and ! -f $opt{c}); 
+unshift(@credentials,$opt{c}) if ($opt{c}); 
+
 if ($opt{e})
 { 
   if ($ENV{IGUSER} and $ENV{IGPASS} and $ENV{IGAPIKEY}) 
@@ -88,7 +91,6 @@ else
 #  eval { require './credentials.pl' } or 
 
   my $reqok=0; 
-
   map { $reqok ||=eval { require $_ } } @credentials; 
 
   
@@ -106,6 +108,7 @@ else
 You can alternatively use 3 environment variables named IGUSER,IGPASSWORD, IGAPIKEY. 
 The credentials file is searched for in the following paths: 
 @credentials
+You can also use -c path or file. 
 " ;
     $ig=Finance::IG->new(cred(),isdemo=>0,col=>0); 
 
@@ -228,7 +231,14 @@ my $out="stdout";
 $ig->login(); 
 
 my $p=$ig->positions(); 
-$p=$ig->agg($p,$sortlist); 
+if ($opt{a})
+{ 
+   $p=$ig->agg($p,$sortlist); 
+} 
+else
+{ 
+   $p=$ig->nonagg($p,$sortlist); 
+} 
 # $ig->sorter(['-atrisk'],$p); 
 
 printf "%d Positions\n",@$p+0 if (!$opt{S}); 
@@ -358,7 +368,11 @@ sub help
 # h help
 # g grep  
 # s print NO summary line 
-   print "$mess\n" if (length($mess)>1);  
+
+   my $name=$0; 
+   $name=~s#^.*/([^/]+)$#$1#; 
+   print "$mess\n" if (defined $mess and length($mess)>1);  
+   print "$name Version $VERSION\n"; 
    print "
 This program is both an example of usage and a practical utility in its own right. 
 
@@ -368,6 +382,7 @@ or 1 or 2 directories up or the current directory. Or you can set
 the environment variables IGPASS, IGUSER, IGAPIKEY.  
 
 The default display is decending order of percent profit.  Various formats are possible. 
+-a n aggregate 1 (default) , nonaggregate 0 = show individual holdings
 -e explain where credentials for login are coming from, then exit. 
 -o Send output to an autogenerated, time based file. 
 -f n use one of the inbuilt formats 1 to 5. 
@@ -395,7 +410,7 @@ The default display is decending order of percent profit.  Various formats are p
    Equal to means with ref to the format so that 
    2020/11/05 means the days are equal while 2020/11 means amy time that month 
 "; 
-exit 1 if (length($mess)>1); 
+exit 1 if (defined $mess and length($mess)>1); 
 print "A complete list of fields in a position isi as follows. Some of these 
 are IG things, and some are calculated: 
 
